Connect

Struct Connect 

pub struct Connect { /* private fields */ }
Represents an MQTT Connect packet

This packet initiates a connection between client and broker and contains all necessary parameters for the session.

Example

use std::time::Duration;
use bytes::Bytes;
use mqute_codec::protocol::{v5, Credentials, Protocol, QoS};

let connect = v5::Connect::new(
    "client",
    Some(Credentials::full("user", "pass")),
    Some(v5::Will::new(
        None,
        "device/status",
        Bytes::from("disconnected"),
        QoS::ExactlyOnce,
        true
    )),
    Duration::from_secs(30),
    true
);
assert!(connect.will().is_some());
assert_eq!(connect.protocol(), Protocol::V5);
assert_eq!(connect.client_id(), "client");

Implementations

Source

impl Connect

pub fn new<S: Into<String>>( client_id: S, credentials: Option<Credentials>, will: Option<Will>, keep_alive: Duration, clean_session: bool, ) -> Self

Creates a new Connect packet with basic parameters

Panics

Panics if the value of the “keep alive” parameter exceeds 65535

pub fn protocol(&self) -> Protocol

Returns the protocol version being used

pub fn keep_alive(&self) -> Duration

Returns the keep alive time in seconds

pub fn clean_session(&self) -> bool

Returns whether this is a clean session

pub fn client_id(&self) -> String

Returns the client identifier

pub fn credentials(&self) -> Option<Credentials>

Returns the authentication credentials if present

pub fn will(&self) -> Option<Will>

Returns the will message if present