#[repr(u8)]pub enum ConnectReturnCode {
Success = 0,
UnacceptableProtocolVersion = 1,
IdentifierRejected = 2,
ServerUnavailable = 3,
BadAuthData = 4,
NotAuthorized = 5,
}Expand description
Represents the return codes for a connection attempt in the MQTT protocol.
The ConnectReturnCode enum is used in the ConnAck packet to indicate the result
of a client’s connection request.
Variants
Success = 0
Connection Accepted
UnacceptableProtocolVersion = 1
The Server does not support the level of the MQTT protocol requested by the Client
IdentifierRejected = 2
The Client identifier is correct UTF-8 but not allowed by the Server
The Network Connection has been made but the MQTT service is unavailable
BadAuthData = 4
The data in the username or password is malformed
NotAuthorized = 5
The Client is not authorized to connect