TopicQosFilters

Struct TopicQosFilters 

pub struct TopicQosFilters(/* private fields */);
Represents a collection of TopicQosFilter instances.

Example

use mqute_codec::protocol::v4::{Subscribe, TopicQosFilters, TopicQosFilter};
use mqute_codec::protocol::QoS;

let topic_filters = TopicQosFilters::new(vec![
        TopicQosFilter::new("topic1", QoS::AtLeastOnce),
        TopicQosFilter::new("topic2", QoS::ExactlyOnce),
    ]);

assert_eq!(topic_filters.len(), 2);

Implementations

Source

impl TopicQosFilters

pub fn new<T: IntoIterator<Item = TopicQosFilter>>(filters: T) -> Self

Creates a new TopicQosFilters instance from an iterator of TopicQosFilter.

Panics

Panics if:

  • The iterator is empty, as at least one topic filter is required.
  • The topic filters are invalid according to MQTT topic naming rules.
pub fn len(&self) -> usize

Returns the number of topic filters in the collection.